package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.generators.DHParametersGenerator;
import cn.com.infosec.crypto.generators.DSAParametersGenerator;
import cn.com.infosec.crypto.generators.ElGamalParametersGenerator;
import cn.com.infosec.crypto.generators.GOST3410ParametersGenerator;
import cn.com.infosec.crypto.params.DHParameters;
import cn.com.infosec.crypto.params.DSAParameters;
import cn.com.infosec.crypto.params.ElGamalParameters;
import cn.com.infosec.crypto.params.GOST3410Parameters;
import cn.com.infosec.jce.spec.GOST3410ParameterSpec;
import cn.com.infosec.jce.spec.GOST3410PublicKeyParameterSetSpec;
import java.math.BigInteger;
import java.security.AlgorithmParameterGeneratorSpi;
import java.security.AlgorithmParameters;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidParameterException;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import java.security.spec.DSAParameterSpec;
import javax.crypto.spec.DHGenParameterSpec;
import javax.crypto.spec.DHParameterSpec;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.RC2ParameterSpec;

public abstract class JDKAlgorithmParameterGenerator extends AlgorithmParameterGeneratorSpi {
   protected SecureRandom random;
   protected int strength = 1024;

   protected void engineInit(int strength, SecureRandom random) {
      this.strength = strength;
      this.random = random;
   }

   public static class DES extends JDKAlgorithmParameterGenerator {
      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         throw new InvalidAlgorithmParameterException("No supported AlgorithmParameterSpec for DES parameter generation.");
      }

      protected AlgorithmParameters engineGenerateParameters() {
         byte[] var1 = new byte[8];
         if (super.random == null) {
            SecureRandom var2;
            var2 = new SecureRandom.<init>();
            super.random = var2;
         }

         super.random.nextBytes(var1);

         try {
            AlgorithmParameters var10000 = AlgorithmParameters.getInstance("DES", "INFOSEC");
            var10000.init(new IvParameterSpec(var1));
            return var10000;
         } catch (Exception var3) {
            throw new RuntimeException(var3.getMessage());
         }
      }
   }

   public static class DH extends JDKAlgorithmParameterGenerator {
      private int l = 0;

      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         if (genParamSpec instanceof DHGenParameterSpec) {
            DH var10000 = this;
            DH var10002 = this;
            DHGenParameterSpec var3;
            super.strength = (var3 = (DHGenParameterSpec)genParamSpec).getPrimeSize();
            var10002.l = var3.getExponentSize();
            var10000.random = random;
         } else {
            throw new InvalidAlgorithmParameterException("DH parameter generator requires a DHGenParameterSpec for initialisation");
         }
      }

      protected AlgorithmParameters engineGenerateParameters() {
         DHParametersGenerator var1;
         var1 = new DHParametersGenerator.<init>();
         SecureRandom var2;
         int var13;
         if ((var2 = super.random) != null) {
            var1.init(super.strength, 20, var2);
         } else {
            var13 = super.strength;
            SecureRandom var3;
            var3 = new SecureRandom.<init>();
            var1.init(var13, 20, var3);
         }

         DHParameters var11 = var1.generateParameters();

         Exception var10000;
         label46: {
            AlgorithmParameters var14;
            AlgorithmParameters var15;
            boolean var10001;
            DHParameterSpec var10002;
            DHParameterSpec var10003;
            DH var10004;
            DHParameters var10005;
            BigInteger var10006;
            try {
               var14 = AlgorithmParameters.getInstance("DH", "INFOSEC");
               var15 = var14;
               var10002 = new DHParameterSpec;
               var10003 = var10002;
               var10004 = this;
               var10005 = var11;
               var10006 = var11.getP();
            } catch (Exception var7) {
               var10000 = var7;
               var10001 = false;
               break label46;
            }

            BigInteger var9 = var10006;

            BigInteger var8;
            try {
               var8 = var10005.getG();
            } catch (Exception var6) {
               var10000 = var6;
               var10001 = false;
               break label46;
            }

            BigInteger var12 = var8;

            int var16;
            try {
               var16 = var10004.l;
            } catch (Exception var5) {
               var10000 = var5;
               var10001 = false;
               break label46;
            }

            var13 = var16;

            try {
               var10003.<init>(var9, var12, var13);
               var15.init(var10002);
               return var14;
            } catch (Exception var4) {
               var10000 = var4;
               var10001 = false;
            }
         }

         Exception var10 = var10000;
         throw new RuntimeException(var10.getMessage());
      }
   }

   public static class DSA extends JDKAlgorithmParameterGenerator {
      protected void engineInit(int strength, SecureRandom random) {
         if (strength >= 512 && strength <= 1024 && strength % 64 == 0) {
            super.strength = strength;
            super.random = random;
         } else {
            throw new InvalidParameterException("strength must be from 512 - 1024 and a multiple of 64");
         }
      }

      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         throw new InvalidAlgorithmParameterException("No supported AlgorithmParameterSpec for DSA parameter generation.");
      }

      protected AlgorithmParameters engineGenerateParameters() {
         DSAParametersGenerator var1;
         var1 = new DSAParametersGenerator.<init>();
         SecureRandom var2;
         if ((var2 = super.random) != null) {
            var1.init(super.strength, 20, var2);
         } else {
            int var8 = super.strength;
            var2 = new SecureRandom.<init>();
            var1.init(var8, 20, var2);
         }

         DSAParameters var9 = var1.generateParameters();

         Exception var10000;
         label46: {
            AlgorithmParameters var14;
            AlgorithmParameters var15;
            boolean var10001;
            DSAParameterSpec var10002;
            DSAParameterSpec var10003;
            DSAParameters var10004;
            DSAParameters var10005;
            BigInteger var10006;
            try {
               var14 = AlgorithmParameters.getInstance("DSA", "INFOSEC");
               var15 = var14;
               var10002 = new DSAParameterSpec;
               var10003 = var10002;
               var10004 = var9;
               var10005 = var9;
               var10006 = var9.getP();
            } catch (Exception var6) {
               var10000 = var6;
               var10001 = false;
               break label46;
            }

            BigInteger var10 = var10006;

            BigInteger var7;
            try {
               var7 = var10005.getQ();
            } catch (Exception var5) {
               var10000 = var5;
               var10001 = false;
               break label46;
            }

            BigInteger var12 = var7;

            BigInteger var16;
            try {
               var16 = var10004.getG();
            } catch (Exception var4) {
               var10000 = var4;
               var10001 = false;
               break label46;
            }

            BigInteger var13 = var16;

            try {
               var10003.<init>(var10, var12, var13);
               var15.init(var10002);
               return var14;
            } catch (Exception var3) {
               var10000 = var3;
               var10001 = false;
            }
         }

         Exception var11 = var10000;
         throw new RuntimeException(var11.getMessage());
      }
   }

   public static class ElGamal extends JDKAlgorithmParameterGenerator {
      private int l = 0;

      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         if (genParamSpec instanceof DHGenParameterSpec) {
            ElGamal var10000 = this;
            ElGamal var10002 = this;
            DHGenParameterSpec var3;
            super.strength = (var3 = (DHGenParameterSpec)genParamSpec).getPrimeSize();
            var10002.l = var3.getExponentSize();
            var10000.random = random;
         } else {
            throw new InvalidAlgorithmParameterException("DH parameter generator requires a DHGenParameterSpec for initialisation");
         }
      }

      protected AlgorithmParameters engineGenerateParameters() {
         ElGamalParametersGenerator var1;
         var1 = new ElGamalParametersGenerator.<init>();
         SecureRandom var2;
         int var13;
         if ((var2 = super.random) != null) {
            var1.init(super.strength, 20, var2);
         } else {
            var13 = super.strength;
            SecureRandom var3;
            var3 = new SecureRandom.<init>();
            var1.init(var13, 20, var3);
         }

         ElGamalParameters var11 = var1.generateParameters();

         Exception var10000;
         label46: {
            AlgorithmParameters var14;
            AlgorithmParameters var15;
            boolean var10001;
            DHParameterSpec var10002;
            DHParameterSpec var10003;
            ElGamal var10004;
            ElGamalParameters var10005;
            BigInteger var10006;
            try {
               var14 = AlgorithmParameters.getInstance("ElGamal", "INFOSEC");
               var15 = var14;
               var10002 = new DHParameterSpec;
               var10003 = var10002;
               var10004 = this;
               var10005 = var11;
               var10006 = var11.getP();
            } catch (Exception var7) {
               var10000 = var7;
               var10001 = false;
               break label46;
            }

            BigInteger var9 = var10006;

            BigInteger var8;
            try {
               var8 = var10005.getG();
            } catch (Exception var6) {
               var10000 = var6;
               var10001 = false;
               break label46;
            }

            BigInteger var12 = var8;

            int var16;
            try {
               var16 = var10004.l;
            } catch (Exception var5) {
               var10000 = var5;
               var10001 = false;
               break label46;
            }

            var13 = var16;

            try {
               var10003.<init>(var9, var12, var13);
               var15.init(var10002);
               return var14;
            } catch (Exception var4) {
               var10000 = var4;
               var10001 = false;
            }
         }

         Exception var10 = var10000;
         throw new RuntimeException(var10.getMessage());
      }
   }

   public static class GOST3410 extends JDKAlgorithmParameterGenerator {
      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         throw new InvalidAlgorithmParameterException("No supported AlgorithmParameterSpec for GOST3410 parameter generation.");
      }

      protected AlgorithmParameters engineGenerateParameters() {
         GOST3410ParametersGenerator var1;
         var1 = new GOST3410ParametersGenerator.<init>();
         SecureRandom var2;
         if ((var2 = super.random) != null) {
            var1.init(super.strength, 2, var2);
         } else {
            int var7 = super.strength;
            var2 = new SecureRandom.<init>();
            var1.init(var7, 2, var2);
         }

         GOST3410Parameters var8 = var1.generateParameters();

         Exception var10000;
         label46: {
            AlgorithmParameters var15;
            AlgorithmParameters var16;
            boolean var10001;
            GOST3410ParameterSpec var10002;
            GOST3410ParameterSpec var10003;
            GOST3410PublicKeyParameterSetSpec var10004;
            GOST3410PublicKeyParameterSetSpec var10005;
            GOST3410Parameters var10006;
            GOST3410Parameters var10007;
            BigInteger var10008;
            try {
               var15 = AlgorithmParameters.getInstance("GOST3410", "INFOSEC");
               var16 = var15;
               var10002 = new GOST3410ParameterSpec;
               var10003 = var10002;
               var10004 = new GOST3410PublicKeyParameterSetSpec;
               var10005 = var10004;
               var10006 = var8;
               var10007 = var8;
               var10008 = var8.getP();
            } catch (Exception var6) {
               var10000 = var6;
               var10001 = false;
               break label46;
            }

            BigInteger var9 = var10008;

            BigInteger var13;
            try {
               var13 = var10007.getQ();
            } catch (Exception var5) {
               var10000 = var5;
               var10001 = false;
               break label46;
            }

            BigInteger var12 = var13;

            BigInteger var10;
            try {
               var10 = var10006.getA();
            } catch (Exception var4) {
               var10000 = var4;
               var10001 = false;
               break label46;
            }

            BigInteger var14 = var10;

            try {
               var10005.<init>(var9, var12, var14);
               var10003.<init>(var10004);
               var16.init(var10002);
               return var15;
            } catch (Exception var3) {
               var10000 = var3;
               var10001 = false;
            }
         }

         Exception var11 = var10000;
         throw new RuntimeException(var11.getMessage());
      }
   }

   public static class IDEA extends JDKAlgorithmParameterGenerator {
      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         throw new InvalidAlgorithmParameterException("No supported AlgorithmParameterSpec for IDEA parameter generation.");
      }

      protected AlgorithmParameters engineGenerateParameters() {
         byte[] var1 = new byte[8];
         if (super.random == null) {
            SecureRandom var2;
            var2 = new SecureRandom.<init>();
            super.random = var2;
         }

         super.random.nextBytes(var1);

         try {
            AlgorithmParameters var10000 = AlgorithmParameters.getInstance("IDEA", "INFOSEC");
            var10000.init(new IvParameterSpec(var1));
            return var10000;
         } catch (Exception var3) {
            throw new RuntimeException(var3.getMessage());
         }
      }
   }

   public static class RC2 extends JDKAlgorithmParameterGenerator {
      RC2ParameterSpec spec = null;

      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         if (genParamSpec instanceof RC2ParameterSpec) {
            this.spec = (RC2ParameterSpec)genParamSpec;
         } else {
            throw new InvalidAlgorithmParameterException("No supported AlgorithmParameterSpec for RC2 parameter generation.");
         }
      }

      protected AlgorithmParameters engineGenerateParameters() {
         AlgorithmParameters var1;
         Exception var7;
         AlgorithmParameters var10;
         Exception var10000;
         boolean var10001;
         if (this.spec == null) {
            byte[] var9 = new byte[8];
            if (super.random == null) {
               SecureRandom var2;
               var2 = new SecureRandom.<init>();
               super.random = var2;
            }

            super.random.nextBytes(var9);

            AlgorithmParameters var8;
            label36: {
               label54: {
                  try {
                     var10 = AlgorithmParameters.getInstance("RC2", "INFOSEC");
                  } catch (Exception var4) {
                     var10000 = var4;
                     var10001 = false;
                     break label54;
                  }

                  var8 = var10;

                  try {
                     var10.init(new IvParameterSpec(var9));
                     break label36;
                  } catch (Exception var3) {
                     var10000 = var3;
                     var10001 = false;
                  }
               }

               var7 = var10000;
               throw new RuntimeException(var7.getMessage());
            }

            var1 = var8;
            return var1;
         } else {
            label55: {
               try {
                  var10 = AlgorithmParameters.getInstance("RC2", "INFOSEC");
               } catch (Exception var6) {
                  var10000 = var6;
                  var10001 = false;
                  break label55;
               }

               var1 = var10;

               try {
                  var10.init(this.spec);
                  return var1;
               } catch (Exception var5) {
                  var10000 = var5;
                  var10001 = false;
               }
            }

            var7 = var10000;
            throw new RuntimeException(var7.getMessage());
         }
      }
   }
}
